﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;
using Telerik.Charting;
using Telerik.Windows.Controls;
using Telerik.Windows.Controls.ChartView;

namespace WpfApp
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();

            //Set chart axes (required for the series to be displayed):
            this.chart.VerticalAxis = new LinearAxis();
            this.chart.HorizontalAxis = new CategoricalAxis();

            //Set chart grid and palette (for better appearance)
            this.chart.Grid = new CartesianChartGrid() { MajorLinesVisibility = GridLineVisibility.XY };
            this.chart.Palette = ChartPalettes.Windows8;

            //Create 4 series:
            for (int i = 0; i < 4; i++)
            {
                this.chart.Series.Add(new RangeBarSeries()
                {
                    CategoryBinding = new PropertyNameDataPointBinding("MyCategoryProperty"),
                    HighBinding = new PropertyNameDataPointBinding("MyHighProperty"),
                    LowBinding = new PropertyNameDataPointBinding("MyLowProperty"),
                });
            }

            this.chart.Series[0].ItemsSource = this.ViewModel.Data1;
            this.chart.Series[1].ItemsSource = this.ViewModel.Data2;
            this.chart.Series[2].ItemsSource = this.ViewModel.Data3;
            this.chart.Series[3].ItemsSource = this.ViewModel.Data4;
        }

        public MainViewModel ViewModel
        {
            get
            {
                return this.DataContext as MainViewModel;
            }
        }
    }
    
    public class MainViewModel
    {
        public ObservableCollection<PlotInfo> Data1 { get; private set; }

        public ObservableCollection<PlotInfo> Data2 { get; private set; }

        public ObservableCollection<PlotInfo> Data3 { get; private set; }

        public ObservableCollection<PlotInfo> Data4 { get; private set; }

        private static readonly Random rnd = new Random(564);

        public MainViewModel()
        {
            this.Data1 = GetTestData(4);
            this.Data2 = GetTestData(4);
            this.Data3 = GetTestData(4);
            this.Data4 = GetTestData(4);
        }

        private static ObservableCollection<PlotInfo> GetTestData(int dataSize)
        {
            var result = new ObservableCollection<PlotInfo>();

            for (int i = 0; i < dataSize; i++)
            {
                double min = rnd.Next(10, 100);
                double max = rnd.Next(10, 100);

                result.Add(new PlotInfo("X" + i, min, max));
            }

            return result;
        }
    }

    public class PlotInfo
    {
        public PlotInfo(string category, double high, double low)
        {
            SwapIfGreater(ref low, ref high);
            this.MyCategoryProperty = category;
            this.MyHighProperty = high;
            this.MyLowProperty = low;
        }

        public string MyCategoryProperty { get; set; }

        public double MyHighProperty { get; set; }

        public double MyLowProperty { get; set; }

        private static void SwapIfGreater(ref double min, ref double max)
        {
            if (min > max)
            {
                double swap = min;
                min = max;
                max = swap;
            }
        }
    }
}